==> ev_framework-3.0.2.tar.gz: lib/_FrameWork/Ev/_Form_Select.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vBox.dart';
import '../vButton.dart';
import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';
import '../vPopup.dart';

class $$Form_Select extends StatefulWidget {
  vForm form;
  var skey;
  String value;
  List data;
  var onchange;
  var max_select;
  String  max_select_error;
  TextEditingController controller;
  var label_text;

  $$Form_Select(Key key,this.skey,this.form,this.value,this.controller,
      { this.label_text,this.data,this.onchange,this.max_select=1,this.max_select_error=""}):super(key:key);

  @override
  _FormSelect_textState createState() => _FormSelect_textState();
}

class _FormSelect_textState extends State<$$Form_Select> {
  var value;
  List listvalue = [];
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    if(widget.max_select>1 && widget.value!="")
      {  listvalue = widget.value.split(",");}
    else
      { value = widget.value; }
    form = widget.form;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
     Widget c =  TextField(
       readOnly: true,
       textAlign: form.$$_Text_Align,
       style: TextStyle(
           fontSize: form.$$_Input_Size, color: form.$$_Input_Color),

       decoration: new InputDecoration(
         border: InputBorder.none,
         contentPadding: EdgeInsets.all(8),
         counterText: "",
         isDense: true,
       ),
       controller: widget.controller,
     );;

       c = Row(children: [
         Expanded(child: c),
         SizedBox(width: 5,),
         Icon(
           Icons.arrow_forward_ios,
           color: Colors.black54,
           size: 26,
         ),
         SizedBox(width: 5,),
       ],);

     if (form.$$_Border_type == 1) {
         c = form_type1(c);}

     if (form.$$_Border_type == 2) {
         c = form_type2(c);}

     return GestureDetector(child:c,
       onTap: (){
          if(widget.max_select<=1)
           { vPopup.$Widget(context,max_height: 600, max_width: 800,
               child:_list_single(data: widget.data,formselect:widget,onchange: (value){
               vPopup.$Widget_close();
               setState(() {
                   this.value = value;
                   widget.controller.text = value;
                   if(widget.onchange != null)
                     {  widget.onchange(value); }
               });
           })); }
          else
            { vPopup.$Widget(context,max_height: 600,max_width: 800,
              child:_list_multi(data: widget.data,formselect:widget,indata: listvalue,
              onClose: (){  vPopup.$Widget_close();},
              onChange: (value){
                 setState(() {
                   this.listvalue = value;
                   widget.controller.text = value.join(",");
                   if(widget.onchange != null)
                     {  widget.onchange(value); }
              });
            }));


            }
        },
     );
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";


    return Padding(
      padding: const EdgeInsets.only(top: 10.0,bottom: 0),
      child: Container(
        padding: form.$$_Padding,
        color:Colors.transparent,
        child: Column(
          crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
          children: <Widget>[
            (form.$$_Lable_ratio > 0) ?
            Row(
                children: <Widget>[
                  Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                  SizedBox(width: 10),
                  Expanded(flex: 100,child: child)
                ]):

            Row(
                children: <Widget>[
                  Padding(
                    padding: const EdgeInsets.only(bottom:8.0),
                    child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                  ),
                  SizedBox(width: 10),
                  Expanded(child: child)
                ]),

            Container(color: color, height: 1,),
            Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
              textAlign: TextAlign.right,),
          ],
        ),
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";


    var decoration = BoxDecoration(
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
      padding: form.$$_Margin,
      color:Colors.transparent,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom: 8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                    ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                      decoration: decoration,

                    ),
                    Padding(
                      padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                      child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }
}


class _list_single extends StatelessWidget {
   List data;
   var onchange;
   $$Form_Select formselect;
   _list_single({this.data,this.onchange,this.formselect});

  @override
  Widget build(BuildContext context) {

    return vBox(child:
        Column(
          children: [
            Container(child:Center(child:vText(formselect.label_text).c(formselect.form.$$_Lable_Color)),color:formselect.form.$$_Border_Color),
            Expanded(
              child: Material(
                child: ListView.separated(
                   separatorBuilder: (context, index) => Divider(
                   color: Colors.grey,
                     height: 1,
                 ),
                itemCount: data.length,
                itemBuilder: (BuildContext build, int index) {
                     return ListTile(
                         contentPadding: EdgeInsets.symmetric(horizontal: 10),
                          title: vText(data[index]).p(0),
                          onTap: (){  onchange(data[index]); }
                     );
      }),
              ),
            ),
          ],
        )
     ).c(Colors.white).r(5);
  }
}


class  _list_multi extends StatefulWidget {
  List data;
  List indata;

  var onChange;
  var onClose;
  $$Form_Select formselect;
  _list_multi({this.data,this.indata,this.onChange,this.onClose,this.formselect});

  @override
  _list_multi_State createState() => _list_multi_State();
}

class _list_multi_State extends State<_list_multi> {
  @override
  Widget build(BuildContext context) {
   return vBox(child:
      Column(
      children: [
        Container(child:Center(child:vText(widget.formselect.label_text).c(widget.formselect.form.$$_Lable_Color)),color:widget.formselect.form.$$_Border_Color),
        Expanded(
          child: Material(
            child: ListView.separated(
                separatorBuilder: (context, index) => Divider(
                  color: Colors.grey,
                  height: 1,
                ),
                itemCount: widget.data.length,
                itemBuilder: (BuildContext build, int index) {
                   var d = widget.data[index];
                   var icon = widget.indata.contains(d) ?
                      Icon(Icons.check_box,color:Colors.orange,size: 25,) :
                      Icon(Icons.check_box_outline_blank,color:Colors.grey,size: 25);

                    return ListTile(
                      leading: icon,
                      contentPadding: EdgeInsets.symmetric(horizontal: 10),
                      title: vText(widget.data[index]).p(0),
                      onTap: (){
                        //print("on Tap " + widget.indata.toString() + widget.indata.length.toString());
                        if(widget.indata.contains(d))
                          {  widget.indata.remove(d); }
                        else
                          {  //print("Add select");
                            if(widget.indata.length >= widget.formselect.max_select)
                               {  //print("Error");
                                  vPopup.$Error(context, widget.formselect.max_select_error);
                               }
                              else
                                {  //print("Add");
                                   widget.indata.add(d);
                                }
                          }


                        setState(() {
                           widget.onChange(widget.indata);

                        });
                      }
                  );
                }),
          ),
        ),
        SizedBox(height: 5,),
        vButton("close").onPress((){
            if(widget.onClose!=null)
               { widget.onClose(); }
        }).wf().outline()
      ],
     )
    ).c(Colors.white).r(5);
  }
}

==> ev_framework-3.0.10.tar.gz: lib/_FrameWork/Ev/_Form_Select.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vBox.dart';
import '../vButton.dart';
import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';
import '../vPopup.dart';

class $$Form_Select extends StatefulWidget {
  vForm form;
  var skey;
  String value;
  List data;
  var onchange;
  var max_select;
  String  max_select_error;
  TextEditingController controller;
  var label_text;

  $$Form_Select(Key key,this.skey,this.form,this.value,this.controller,
      { this.label_text,this.data,this.onchange,this.max_select=1,this.max_select_error=""}):super(key:key);

  @override
  _FormSelect_textState createState() => _FormSelect_textState();
}

class _FormSelect_textState extends State<$$Form_Select> {
  var value;
  List listvalue = [];
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    if(widget.max_select>1 && widget.value!="")
      {  listvalue = widget.value.split(",");}
    else
      { value = widget.value; }
    form = widget.form;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
     Widget c =  TextField(
       readOnly: true,
       textAlign: form.$$_Text_Align,
       style: TextStyle(
           fontSize: form.$$_Input_Size, color: form.$$_Input_Color),

       decoration: new InputDecoration(
         border: InputBorder.none,
         contentPadding: EdgeInsets.all(8),
         counterText: "",
         isDense: true,
       ),
       controller: widget.controller,
     );;

       c = Row(children: [
         Expanded(child: c),
         SizedBox(width: 5,),
         Icon(
           Icons.arrow_forward_ios,
           color: Colors.black54,
           size: 26,
         ),
         SizedBox(width: 5,),
       ],);

     if (form.$$_Border_type == 1) {
         c = form_type1(c);}

     if (form.$$_Border_type == 2) {
         c = form_type2(c);}

     return GestureDetector(child:c,
       onTap: (){
          if(widget.max_select<=1)
           { vPopup.$Widget(context,max_height: 600, max_width: 800,
               child:_list_single(data: widget.data,formselect:widget,onchange: (value){
               vPopup.$Widget_close();
               setState(() {
                   this.value = value;
                   widget.controller.text = value;
                   if(widget.onchange != null)
                     {  widget.onchange(value); }
               });
           })); }
          else
            { vPopup.$Widget(context,max_height: 600,max_width: 800,
              child:_list_multi(data: widget.data,formselect:widget,indata: listvalue,
              onClose: (){  vPopup.$Widget_close();},
              onChange: (value){
                 setState(() {
                   this.listvalue = value;
                   widget.controller.text = value.join(",");
                   if(widget.onchange != null)
                     {  widget.onchange(value); }
              });
            }));


            }
        },
     );
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";


    return Padding(
      padding: const EdgeInsets.only(top: 10.0,bottom: 0),
      child: Container(
        padding: form.$$_Margin,
        color:Colors.transparent,
        child: Column(
          crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
          children: <Widget>[
            Padding(padding: form.$$_Padding,child:(form.$$_Lable_ratio > 0) ?
            Row(
                children: <Widget>[
                  Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                  SizedBox(width: 10),
                  Expanded(flex: 100,child: child)
                ]):

            Row(
                children: <Widget>[
                  vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                  SizedBox(width: 10),
                  Expanded(child: child)
                ]),
            ),
            Container(color: color, height: 1,),
            Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
              textAlign: TextAlign.right,),
          ],
        ),
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";


    var decoration = BoxDecoration(
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
      padding: form.$$_Margin,
      color:Colors.transparent,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom: 8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                    ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                      decoration: decoration,

                    ),
                    Padding(
                      padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                      child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }
}


class _list_single extends StatelessWidget {
   List data;
   var onchange;
   $$Form_Select formselect;
   _list_single({this.data,this.onchange,this.formselect});

  @override
  Widget build(BuildContext context) {

    return vBox(child:
        Column(
          children: [
            Container(child:Center(child:vText(formselect.label_text).c(formselect.form.$$_Lable_Color)),color:formselect.form.$$_Border_Color),
            Expanded(
              child: Material(
                child: ListView.separated(
                   separatorBuilder: (context, index) => Divider(
                   color: Colors.grey,
                     height: 1,
                 ),
                itemCount: data.length,
                itemBuilder: (BuildContext build, int index) {
                     return ListTile(
                         contentPadding: EdgeInsets.symmetric(horizontal: 10),
                          title: vText(data[index]).p(0),
                          onTap: (){  onchange(data[index]); }
                     );
      }),
              ),
            ),
          ],
        )
     ).c(Colors.white).r(5).h(500);
  }
}


class  _list_multi extends StatefulWidget {
  List data;
  List indata;

  var onChange;
  var onClose;
  $$Form_Select formselect;
  _list_multi({this.data,this.indata,this.onChange,this.onClose,this.formselect});

  @override
  _list_multi_State createState() => _list_multi_State();
}

class _list_multi_State extends State<_list_multi> {
  @override
  Widget build(BuildContext context) {
   return vBox(child:
      Column(
      children: [
        Container(child:Center(child:vText(widget.formselect.label_text).c(widget.formselect.form.$$_Lable_Color)),color:widget.formselect.form.$$_Border_Color),
        Expanded(
          child: Material(
            child: ListView.separated(
                separatorBuilder: (context, index) => Divider(
                  color: Colors.grey,
                  height: 1,
                ),
                itemCount: widget.data.length,
                itemBuilder: (BuildContext build, int index) {
                   var d = widget.data[index];
                   var icon = widget.indata.contains(d) ?
                      Icon(Icons.check_box,color:Colors.orange,size: 25,) :
                      Icon(Icons.check_box_outline_blank,color:Colors.grey,size: 25);

                    return ListTile(
                      leading: icon,
                      contentPadding: EdgeInsets.symmetric(horizontal: 10),
                      title: vText(widget.data[index]).p(0),
                      onTap: (){
                        //print("on Tap " + widget.indata.toString() + widget.indata.length.toString());
                        if(widget.indata.contains(d))
                          {  widget.indata.remove(d); }
                        else
                          {  //print("Add select");
                            if(widget.indata.length >= widget.formselect.max_select)
                               {  //print("Error");
                                  vPopup.$Error(context, widget.formselect.max_select_error);
                               }
                              else
                                {  //print("Add");
                                   widget.indata.add(d);
                                }
                          }


                        setState(() {
                           widget.onChange(widget.indata);

                        });
                      }
                  );
                }),
          ),
        ),
        SizedBox(height: 5,),
        vButton("close").onPress((){
            if(widget.onClose!=null)
               { widget.onClose(); }
        }).wf().outline()
      ],
     )
    ).c(Colors.white).r(5).h(500);
  }
}
